pub trait StrToBits<'a> {
// Required method
fn iter_bits(&'a self) -> StrBitIter<'a> ⓘ;
// Provided method
fn to_bit_vec(&'a self) -> Vec<bool> { ... }
}Expand description
Trait for converting bit strings into a bit iterator.
Required Methods
Sourcefn iter_bits(&'a self) -> StrBitIter<'a> ⓘ
fn iter_bits(&'a self) -> StrBitIter<'a> ⓘ
Converts a bit string into a bit iterator.
The returned iterator will yield true for any character that is not '0',
Provided Methods
Sourcefn to_bit_vec(&'a self) -> Vec<bool>
fn to_bit_vec(&'a self) -> Vec<bool>
Converts a bit string into a bit vector.
The returned vector will contain true for any character that is not '0',
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".